==> haskell-implicit-hie-cradle-0.3.0.5-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 implicit-hie-cradle
version:              0.3.0.5
visibility:           public
id:                   implicit-hie-cradle-0.3.0.5-HxhooJnndV51bT6ts0ijr8
key:                  implicit-hie-cradle-0.3.0.5-HxhooJnndV51bT6ts0ijr8
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  a033c989f78734a6819f8e772cd3d8fc
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.0.1/site-local/implicit-hie-cradle-0.3.0.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/implicit-hie-cradle-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/implicit-hie-cradle-0.3.0.5

hs-libraries:         HSimplicit-hie-cradle-0.3.0.5-HxhooJnndV51bT6ts0ijr8
depends:
    base-4.15.0.0 base16-bytestring-1.0.1.0-ACUewSgXa2lGPxnToJIotQ
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.1
    extra-1.7.10-Ic4saaul5v2Abuas5lK2xt filepath-1.4.2.1
    hie-bios-0.7.6-68uRpgoXpCTGZk2NZL2FIH
    hslogger-1.3.1.0-2AG1ImTRkk7Cy6tgOIQFJE
    implicit-hie-0.1.2.6-9C4VS23zCHw1a2334rj27U process-1.6.11.0
    temporary-1.3-6FIxg0ZrJD07j9FbKd9D73 text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn
    unordered-containers-0.2.14.0-7Twq3Q78XsnAV2eREMKYwX
    vector-0.12.3.1-HMAplmdcuCN6dtD8e6QGwL
    yaml-0.11.7.0-Jun1Bygz2RQJsBY1YHmerG

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-cradle-0.3.0.5-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie-cradle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 implicit-hie-cradle
version:              0.3.0.5
visibility:           public
id:                   implicit-hie-cradle-0.3.0.5-IeBs0BKVYPiKTzLCOQy6Yl
key:                  implicit-hie-cradle-0.3.0.5-IeBs0BKVYPiKTzLCOQy6Yl
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie-cradle#readme
synopsis:             Auto generate hie-bios cradles
description:          Auto generate a stack or cabal multi component cradles
category:             Development, Tools, Hie, HLS
abi:                  81be6afc61e40fa8c37b0ac4a2559e82
exposed:              True
exposed-modules:      Hie.Implicit.Cradle
hidden-modules:       Paths_implicit_hie_cradle
import-dirs:          /usr/lib/ghc-9.0.1/site-local/implicit-hie-cradle-0.3.0.5
library-dirs:         /usr/lib/ghc-9.0.1/site-local/implicit-hie-cradle-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/implicit-hie-cradle-0.3.0.5

hs-libraries:         HSimplicit-hie-cradle-0.3.0.5-IeBs0BKVYPiKTzLCOQy6Yl
depends:
    base-4.15.0.0 base16-bytestring-1.0.1.0-1W0eOyz2lRFFHRqvFSDAjG
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.1
    extra-1.7.10-DzxxpLYsMb6EhOaVSpdkFl filepath-1.4.2.1
    hie-bios-0.7.6-KxrdXPdpRYZLJJVzWbMHxx
    hslogger-1.3.1.0-JP8me9dXZa34IDFtlj3zUN
    implicit-hie-0.1.2.6-AWVZD2WzvhY9pOpXoLL2Mg process-1.6.11.0
    temporary-1.3-ENCyyVZZPo5JGPBvyXcA6D text-1.2.4.1 time-1.9.3
    transformers-0.5.6.2 unix-compat-0.5.3-CsWJk3UHZrh7lbWn5tdOhn
    unordered-containers-0.2.14.0-EvtGmSgibELG8puyj0bZfl
    vector-0.12.3.1-BYdg1PRFj4WB38iHU29MVy
    yaml-0.11.7.0-G8x7P15GRT571rujfe2Tz0

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie-cradle/html/implicit-hie-cradle.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie-cradle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
